<script>
    var style = getComputedStyle(document.body);
    var theme = {};
    theme.primary = style.getPropertyValue('--primary');
    theme.secondary = style.getPropertyValue('--secondary');
    theme.success = style.getPropertyValue('--success');
    theme.info = style.getPropertyValue('--info');
    theme.warning = style.getPropertyValue('--warning');
    theme.danger = style.getPropertyValue('--danger');
    theme.light = style.getPropertyValue('--light');
    theme.dark = style.getPropertyValue('--dark');
    theme.blue = style.getPropertyValue('--blue');
    theme.indigo = style.getPropertyValue('--indigo');
    theme.purple = style.getPropertyValue('--purple');
    theme.pink = style.getPropertyValue('--pink');
    theme.red = style.getPropertyValue('--red');
    theme.orange = style.getPropertyValue('--orange');
    theme.yellow = style.getPropertyValue('--yellow');
    theme.green = style.getPropertyValue('--green');
    theme.teal = style.getPropertyValue('--teal');
    theme.cyan = style.getPropertyValue('--cyan');
    theme.white = style.getPropertyValue('--white');
    theme.gray = style.getPropertyValue('--gray');
</script>
